import { Component, Input } from "@angular/core";
import { NgbActiveModal } from "@ng-bootstrap/ng-bootstrap";
import { DeviceService } from "../../service/device.service";
import { CostManagementService } from "../../service/cost-management.service";
import { TableexcelService } from "src/app/_services/tableexcel.service";

@Component({
  selector: "app-modal-export",
  templateUrl: "./modal-export.component.html",
  styleUrls: ["./modal-export.component.css"],
})
export class ModalExportComponent {
  @Input() buildingId: number;
  @Input() dataRow: any;
  data: any;
  filteredRows: any[];
  data_device: any[];
  kwhTerm: string = "";
  costTerm: string = "";
  data_cost: any;
  dataExport: any;
  formattedEndDate: any;
  spinnerExportActive = false;
  constructor(
    public activeModal: NgbActiveModal,
    private costService: CostManagementService,
    private tableexcelService: TableexcelService
  ) {}

  ngOnInit() {
    const dateRow = this.convertToUTC7(this.dataRow.endDate)
    this.formattedEndDate = dateRow.slice(0, 7);
  }

  ngAfterViewInit(): void {
    console.log(this.dataRow);
    this.fetchData(
      this.dataRow.categoryId,
      this.dataRow.roomId,
      this.formattedEndDate
    );
  }

  fetchData(category, room, period) {
    this.costService
      .getCostDetail(category, room, period)
      .subscribe((response) => {
        this.dataExport = response.data;
        console.log(this.dataExport);
        this.data_cost = response.data.map((item) => ({
          deviceName: item.device_name,
          roomName: item.room_name,
          categoryName: item.category_name,
          estimationCost: item.estimation_cost,
          totalKwh: item.total_kwh,
          watt: item.watt,
          duration: item.duration,
          priceKwh: item.price_kwh,
          // periode: item.periode,
          periode: this.convertToUTC7(item.periode)
        }));
        console.log(this.data_cost);
        
      });
  }

  convertToUTC7(dateString: string): string {
    const date = new Date(dateString);
    const utc7Offset = 7 * 60; // UTC+7 in minutes
    const localOffset = date.getTimezoneOffset();
    const totalOffset = utc7Offset - localOffset;
    const utc7Date = new Date(date.getTime() + totalOffset * 60 * 1000);
    return utc7Date.toISOString();
  }

  export() {
    this.spinnerExportActive = true;
    setTimeout(() => {
      const columnsToExport = [
        "periode",
        "deviceName",
        "roomName",
        "categoryName",
        "estimationCost",
        "totalKwh",
        "watt",
        "duration",
        "priceKwh",
      ];
      this.tableexcelService.exportAsExcelFileManageDetail(
        this.data_cost,
        "export_detail_cost_management",
        columnsToExport
      );
      this.spinnerExportActive = false;
      this.activeModal.close("Export completed");
    }, 3000);
  }
}
