import { Component, ViewChild } from "@angular/core";
import { FormBuilder, FormGroup, NgForm, Validators, AbstractControl, ValidatorFn } from "@angular/forms";
import { ActivatedRoute, Router } from "@angular/router";

@Component({
  selector: "app-update-password",
  templateUrl: "./update-password.component.html",
  styleUrls: ["./update-password.component.css"],
})
export class UpdatePasswordComponent {
  @ViewChild("f", { read: true }) userProfileForm: NgForm;
  public breadcrumb: any;
  profilInfo: FormGroup;
  activeTab: string = "profile-info2";
  submitted = false;
  showCurrentPass: boolean = false;
  showNewPass: boolean = false;
  showConfirmPass: boolean = false;

  constructor(
    private formBuilder: FormBuilder,
    private router: Router,
    private route: ActivatedRoute
  ) {}

  ngOnInit(): void {
    this.profilInfo = this.formBuilder.group({
      currentPass: ["", Validators.required],
      newPass: ["", [Validators.required, Validators.minLength(8), Validators.pattern(/^(?=.*[a-z])(?=.*[A-Z])(?=.*\d).+$/)]],
      confirmPass: ["", [Validators.required, this.matchPassword('newPass')]],
    });

    this.profilInfo.get('newPass').valueChanges.subscribe(() => {
      this.profilInfo.get('confirmPass').updateValueAndValidity();
    });
  }

  selectTab(tabName: string) {
    this.activeTab = tabName;
  }

  get f() {
    return this.profilInfo.controls;
  }

  matchPassword(passwordControlName: string): ValidatorFn {
    return (control: AbstractControl): { [key: string]: boolean } | null => {
      if (!control.parent || !control) {
        return null;
      }

      const passwordControl = control.parent.get(passwordControlName);
      if (!passwordControl) {
        return null;
      }

      if (passwordControl.value !== control.value) {
        return { matchPassword: true };
      }

      return null;
    };
  }

  onProjectInfoSubmit() {
    this.submitted = true;

    if (this.profilInfo.invalid) {
      return;
    }

    // Handle form submission
  }

  cancel() {
    // Handle cancel action
  }

  saveEdit() {
    // Handle save action
    console.log(this.profilInfo);
    console.log(this.profilInfo.invalid);
    console.log(this.profilInfo.valid);
    
  }

  toggleCurrentPassVisibility() {
    this.showCurrentPass = !this.showCurrentPass;
  }

  toggleNewPassVisibility() {
    this.showNewPass = !this.showNewPass;
  }

  toggleConfirmPassVisibility() {
    this.showConfirmPass = !this.showConfirmPass;
  }
}
